@@ -66,7 +66,7 @@ def get_permissions_info(rqdtac_uri):
     return res['data']
 
 
-def get_license_info(uri, license_name='license'):
+def get_license_info(uri, license_name='RQSDK LICENSE'):
     """从license获取账户的相关信息"""
     if not uri:
         click.echo("当前环境无{}".format(license_name))
@@ -81,17 +81,16 @@ def get_license_info(uri, license_name='license'):
     return _info
 
 
-def get_rqdata_info(uri=None, license_name='rqdatac license'):
+def get_rqdata_info(uri=None, license_name='RQDATA LICENSE'):
     """从rqdata获取账户的相关信息"""
     try:
         rqdatac.init(uri=uri)
         _info = rqdatac.user.get_quota()
     except(AuthenticationFailed, ValueError) as err:
-        click.echo("{}不可用： {}={}".format(license_name, license_name, uri))
-        if err.args:
-            click.echo(err.args[0])
-        return
-    return _info
+        click.echo("{}：{}".format(license_name, uri))
+        click.echo("{} 不可用，原因：【{}】；请使用【rqsdk config --rqdatac】 命令更新".format(license_name, err.args[0]))
+    else:
+        return _info
 
 
 def print_license_info(uri_license=os.environ.get('RQSDK_LICENSE') or os.environ.get('RQDATAC2_CONF'),
