@@ -33,7 +33,7 @@ def pip_install(full_name, index_url):
         click.echo("pip {}".format(command))
     python_path = "\"{}\"".format(sys.executable)
     if sys.platform == "win32":
-        end_help_msg = "& echo 请输入Enter继续..."
+        end_help_msg = "& echo 请按下 Enter（回车）键继续..."
         subprocess.Popen("{} -m pip {} ".format(python_path, command) + end_help_msg, shell=True)
         sys.exit(1)
     else:
