@@ -17,6 +17,6 @@ class RQSDKBackTestTestCase(TestCase):
             from rqalpha_plus import run_func
             from rqalpha.utils.dict_func import deep_update
             base_config = deepcopy(cls.base_config)
-            deep_update(config, cls.base_config)
+            deep_update(config, base_config)
             return run_func(config=base_config, **{f.__name__: f for f in funcs})
         return run
